@@ -112,6 +112,7 @@ class UserModelView(ModelView):
     add_title = lazy_gettext('Add User')
     edit_title = lazy_gettext('Edit User')
 
+    
     label_columns = {'get_full_name': lazy_gettext('Full Name'),
                      'first_name': lazy_gettext('First Name'),
                      'last_name': lazy_gettext('Last Name'),
@@ -127,7 +128,8 @@ class UserModelView(ModelView):
                      'created_by': lazy_gettext('Created by'),
                      'changed_on': lazy_gettext('Changed on'),
                      'changed_by': lazy_gettext('Changed by')}
-
+    
+    
     description_columns = {'first_name': lazy_gettext('Write the user first name or names'),
                            'last_name': lazy_gettext('Write the user last name'),
                            'username': lazy_gettext(
@@ -205,6 +207,7 @@ class UserDBModelView(UserModelView):
 
     add_columns = ['first_name', 'last_name', 'username', 'active', 'email', 'role', 'password', 'conf_password']
 
+
     @expose('/show/<int:pk>', methods=['GET'])
     @has_access
     def show(self, pk):
@@ -252,7 +255,11 @@ class UserDBModelView(UserModelView):
 class UserStatsChartView(DirectByChartView):
     datamodel = SQLAModel(User)
     chart_title = lazy_gettext('User Statistics')
-    label_columns = UserModelView.label_columns
+    label_columns = {'username': lazy_gettext('User Name'),
+                     'login_count': lazy_gettext('Login count'),
+                     'fail_login_count': lazy_gettext('Failed login count')
+                     }
+                     
     search_columns = UserModelView.search_columns
 
     definitions = [
